@@ -63,7 +63,9 @@ def get_reservation_context_details():
                                             res_dict['ownerPass'],
                                             res_dict['id'],
                                             res_dict['environmentPath'],
-                                            get_permitted_users())
+                                            get_permitted_users(),
+                                            res_dict['savedSandboxId'],
+                                            res_dict['runningUser'])
     return res_details
 
 
@@ -156,7 +158,10 @@ def _covert_to_permitted_users_list(permitted_users):
 
 def _get_quali_env_variable_object(name):
     json_string = os.environ[name]
-    json_object = json.loads(json_string)
+    try:
+        json_object = json.loads(json_string)
+    except ValueError:
+        json_object = json.loads(json_string.replace('\\','\\\\'))
     return json_object
 
 
@@ -219,7 +224,7 @@ class ResourceContextDetails:
 class ReservationContextDetails:
     def __init__(self, environment_name, domain, description,
                  parameters, owner_user, owner_password,
-                 reservation_id, environment_path, permitted_users):
+                 reservation_id, environment_path, permitted_users, savedSandboxId, running_user):
         self.environment_name = environment_name
         """:type : str"""
         self.domain = domain
@@ -236,8 +241,12 @@ class ReservationContextDetails:
         """:type : str"""
         self.environment_path = environment_path
         """:type : str"""
+        self.savedSandboxId = savedSandboxId
+        """:type : str"""
         self.permitted_users = permitted_users
         """:type : list[UserDetails]"""
+        self.running_user = running_user
+        """:type : str"""
 
 class UserDetails:
     def __init__(self, user_name, email):
